@@ -71,7 +71,6 @@ public:
     Transaction* installApplication(AbstractResource* app, const AddonList& addons) override;
     Transaction* removeApplication(AbstractResource* app) override;
     bool isFetching() const override { return m_fetching; }
-    AbstractResource * resourceForFile(const QUrl & ) override;
     void checkForUpdates() override;
     QString displayName() const override;
     bool hasApplications() const override;
@@ -84,6 +83,7 @@ Q_SIGNALS:
     void initialized();
 
 private:
+    ResultsStream* resourceForFile(const QUrl & );
     void refreshRemotes();
     void addUpdates();
     void addResourceToList(FwupdResource *res);
