@@ -153,11 +153,13 @@ QUrl AppPackageKitResource::donationURL()
     return m_appdata.url(AppStream::Component::UrlKindDonation);
 }
 
-bool AppPackageKitResource::isTechnical() const
+AbstractResource::Type AppPackageKitResource::type() const
 {
     static QString desktop = QString::fromUtf8(qgetenv("XDG_CURRENT_DESKTOP"));
     const auto desktops = m_appdata.compulsoryForDesktops();
-    return (!desktops.isEmpty() && !desktops.contains(desktop)) || m_appdata.kind() == AppStream::Component::KindAddon;
+    return m_appdata.kind() == AppStream::Component::KindAddon   ? Addon
+           : (desktops.isEmpty() || !desktops.contains(desktop)) ? Application
+                                                                 : Technical;
 }
 
 void AppPackageKitResource::fetchScreenshots()
@@ -177,14 +179,10 @@ QStringList AppPackageKitResource::allPackageNames() const
 
 QList<PackageState> AppPackageKitResource::addonsInformation()
 {
-    const PackageKitBackend* p = static_cast<PackageKitBackend*>(parent());
-    const QVector<AppPackageKitResource*> res = p->extendedBy(m_appdata.id());
-
-    QList<PackageState> ret;
-    Q_FOREACH (AppPackageKitResource* r, res) {
-        ret += PackageState(r->appstreamId(), r->name(), r->comment(), r->isInstalled());
-    }
-    return ret;
+    return kTransform<QList<PackageState>>(
+        backend()->extendedBy(m_appdata.id()),
+        [](AppPackageKitResource* r) { return PackageState(r->appstreamId(), r->name(), r->comment(), r->isInstalled()); }
+    );
 }
 
 QStringList AppPackageKitResource::extends() const
@@ -197,6 +195,13 @@ QString AppPackageKitResource::changelog() const
     return AppStreamUtils::changelogToHtml(m_appdata);
 }
 
+
+bool AppPackageKitResource::canExecute() const
+{
+    static QSet<QString> cannotExecute = { QStringLiteral("org.kde.development") };
+    return !cannotExecute.contains(m_appdata.id());
+}
+
 void AppPackageKitResource::invokeApplication() const
 {
     auto trans = PackageKit::Daemon::getFiles({installedPackageId()});
@@ -205,11 +210,13 @@ void AppPackageKitResource::invokeApplication() const
         if (!allServices.isEmpty()) {
             const auto packageServices = kFilter<QStringList>(allServices, [filenames](const QString &file) { return filenames.contains(file); });
             QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), {packageServices});
+            return;
         } else {
             const QStringList exes = m_appdata.provided(AppStream::Provided::KindBinary).items();
             const auto packageExecutables = kFilter<QStringList>(allServices, [filenames](const QString &exe) { return filenames.contains(QLatin1Char('/') + exe); });
             if (!packageExecutables.isEmpty()) {
                 QProcess::startDetached(exes.constFirst());
+                return;
             } else {
                 const auto locations = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
                 const auto desktopFiles = kFilter<QStringList>(filenames, [locations](const QString &exe) {
@@ -221,9 +228,10 @@ void AppPackageKitResource::invokeApplication() const
                 });
                 if (!desktopFiles.isEmpty()) {
                     QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), { desktopFiles });
+                    return;
                 }
             }
-            qWarning() << "Could not find any executables" << exes << filenames;
+            backend()->passiveMessage(i18n("Cannot launch %1", name()));
         }
     });
 }
@@ -238,6 +246,11 @@ QDate AppPackageKitResource::releaseDate() const
     return {};
 }
 
+QString AppPackageKitResource::author() const
+{
+    return m_appdata.developerName();
+}
+
 void AppPackageKitResource::fetchChangelog()
 {
     emit changelogFetched(changelog());
