@@ -29,6 +29,7 @@
 #include <QDebug>
 #include <KNotification>
 #include <PackageKit/Daemon>
+#include <PackageKit/Offline>
 #include <QDBusInterface>
 #include <QFile>
 #include <QFileSystemWatcher>
@@ -50,6 +51,11 @@ PackageKitNotifier::PackageKitNotifier(QObject* parent)
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::updatesChanged, this, &PackageKitNotifier::recheckSystemUpdateNeeded);
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::isRunningChanged, this, &PackageKitNotifier::recheckSystemUpdateNeeded);
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::transactionListChanged, this, &PackageKitNotifier::transactionListChanged);
+    connect(PackageKit::Daemon::global(), &PackageKit::Daemon::restartScheduled, this, &PackageKitNotifier::nowNeedsReboot);
+    connect(PackageKit::Daemon::global(), &PackageKit::Daemon::changed, this, [this]{
+        if (PackageKit::Daemon::global()->offline()->updateTriggered())
+            nowNeedsReboot();
+    });
 
     //Check if there's packages after 5'
     QTimer::singleShot(5 * 60 * 1000, this, &PackageKitNotifier::refreshDatabase);
@@ -113,7 +119,7 @@ void PackageKitNotifier::checkOfflineUpdates()
     if (!success) {
         const QString errorDetails = group.readEntry("ErrorDetails");
 
-        KNotification *notification = new KNotification(QLatin1String("offlineupdate-failed"), KNotification::Persistent | KNotification::DefaultEvent);
+        KNotification *notification = new KNotification(QStringLiteral("offlineupdate-failed"), KNotification::Persistent | KNotification::DefaultEvent);
         notification->setIconName(QStringLiteral("error"));
         notification->setText(i18n("Offline Updates"));
         notification->setText(i18n("Failed to update %1 packages\n%2", packages.count(), errorDetails));
@@ -122,10 +128,16 @@ void PackageKitNotifier::checkOfflineUpdates()
         connect(notification, &KNotification::action1Activated, this, [] () {
             QProcess::startDetached(QStringLiteral("plasma-discover"));
         });
+        connect(notification, &KNotification::action2Activated, this, [this] () {
+            auto trans = PackageKit::Daemon::global()->repairSystem();
+            connect(trans, &PackageKit::Transaction::errorCode, this, [](PackageKit::Transaction::Error /*error*/, const QString &details){
+                KNotification::event(QStringLiteral("offlineupdate-repair-failed"), i18n("Repair Failed"), i18n("Please report to your distribution: %1", details), {}, KNotification::Persistent, QStringLiteral("org.kde.discovernotifier"));
+            });
+        });
 
         notification->sendEvent();
     } else {
-        KNotification *notification = new KNotification(QLatin1String("offlineupdate-successful"));
+        KNotification *notification = new KNotification(QStringLiteral("offlineupdate-successful"));
         notification->setIconName(QStringLiteral("system-software-update"));
         notification->setTitle(i18n("Offline Updates"));
         notification->setText(i18n("Successfully updated %1 packages", packages.count()));
@@ -141,6 +153,9 @@ void PackageKitNotifier::checkOfflineUpdates()
 
 void PackageKitNotifier::recheckSystemUpdateNeeded()
 {
+    if (PackageKit::Daemon::global()->offline()->updateTriggered())
+        return;
+
     m_recheckTimer->start();
 }
 
@@ -203,53 +218,29 @@ uint PackageKitNotifier::updatesCount()
     return m_normalUpdates;
 }
 
-void PackageKitNotifier::onDistroUpgrade(PackageKit::Transaction::DistroUpgrade type, const QString& name, const QString& description)
+void PackageKitNotifier::onDistroUpgrade(PackageKit::Transaction::DistroUpgrade /*type*/, const QString& name, const QString& description)
 {
-#ifdef PKQT_1_0
-    KNotification *notification = new KNotification(QLatin1String("distupgrade-notification"), KNotification::Persistent | KNotification::DefaultEvent);
-    notification->setIconName(QStringLiteral("system-software-update"));
-    notification->setActions(QStringList{QLatin1String("Upgrade")});
-    notification->setTitle(i18n("Upgrade available"));
-    switch(type) {
-        case PackageKit::Transaction::DistroUpgradeUnknown:
-        case PackageKit::Transaction::DistroUpgradeUnstable:
-            notification->setText(i18n("New unstable version: %1", description));
-            break;
-        case PackageKit::Transaction::DistroUpgradeStable:
-            notification->setText(i18n("New version: %1", description));
-            break;
-    }
-
-    connect(notification, &KNotification::action1Activated, this, [name] () {
+    auto a = new UpgradeAction(name, description, this);
+    connect(a, &UpgradeAction::triggered, this, [] (const QString &name) {
         PackageKit::Daemon::upgradeSystem(name, PackageKit::Transaction::UpgradeKindDefault);
     });
-
-    notification->sendEvent();
-#else
-    Q_UNUSED(type)
-    Q_UNUSED(name)
-    Q_UNUSED(description)
-#endif
+    Q_EMIT foundUpgradeAction(a);
 }
 
 void PackageKitNotifier::refreshDatabase()
 {
     if (!m_refresher) {
         m_refresher = PackageKit::Daemon::refreshCache(false);
-        connect(m_refresher.data(), &PackageKit::Transaction::finished, this, [this]() {
-            recheckSystemUpdateNeeded();
-        });
+        connect(m_refresher.data(), &PackageKit::Transaction::finished, this, &PackageKitNotifier::recheckSystemUpdateNeeded);
     }
 
-#ifdef PKQT_1_0
     if (!m_distUpgrades && (PackageKit::Daemon::roles() & PackageKit::Transaction::RoleUpgradeSystem)) {
         m_distUpgrades = PackageKit::Daemon::getDistroUpgrades();
         connect(m_distUpgrades, &PackageKit::Transaction::distroUpgrade, this, &PackageKitNotifier::onDistroUpgrade);
     }
-#endif
 }
 
-QProcess* PackageKitNotifier::checkAptVariable(const QString &aptconfig, const QLatin1String& varname, std::function<void(const QStringRef& val)> func)
+QProcess* PackageKitNotifier::checkAptVariable(const QString &aptconfig, const QLatin1String& varname, const std::function<void(const QStringRef& val)> &func)
 {
     QProcess* process = new QProcess;
     process->start(aptconfig, {QStringLiteral("dump")});
@@ -275,6 +266,9 @@ QProcess* PackageKitNotifier::checkAptVariable(const QString &aptconfig, const Q
 
 void PackageKitNotifier::transactionListChanged(const QStringList& tids)
 {
+    if (PackageKit::Daemon::global()->offline()->updateTriggered())
+        return;
+
     for (const auto &tid: tids) {
         if (m_transactions.contains(tid))
             continue;
