@@ -27,7 +27,6 @@
 #include <QStandardItemModel>
 #include <KLocalizedString>
 #include <utils.h>
-#include <QProcess>
 
 QDebug operator<<(QDebug debug, const QSnapdPlug& plug)
 {
@@ -220,9 +219,9 @@ void SnapResource::invokeApplication() const
     QProcess::startDetached(QStringLiteral("snap"), {QStringLiteral("run"), packageName()});
 }
 
-bool SnapResource::isTechnical() const
+AbstractResource::Type SnapResource::type() const
 {
-    return m_snap->snapType() != QLatin1String("app");
+    return m_snap->snapType() != QLatin1String("app") ? Application : Technical;
 }
 
 void SnapResource::setSnap(const QSharedPointer<QSnapdSnap>& snap)
@@ -356,6 +355,20 @@ QString SnapResource::channel() const
     return req->error() ? QString() : req->snap()->trackingChannel();
 }
 
+QString SnapResource::author() const
+{
+#ifdef SNAP_PUBLISHER
+    QString author = m_snap->publisherDisplayName();
+    if (m_snap->publisherValidation() == QSnapdEnums::PublisherValidationVerified) {
+        author += QStringLiteral(" ✅");
+    }
+#else
+    QString author;
+#endif
+
+    return author;
+}
+
 void SnapResource::setChannel(const QString& channelName)
 {
 #ifdef SNAP_CHANNELS
