@@ -22,8 +22,8 @@
 #ifndef RESOURCESPROXYMODEL_H
 #define RESOURCESPROXYMODEL_H
 
-#include <QtCore/QSortFilterProxyModel>
-#include <QtCore/QString>
+#include <QSortFilterProxyModel>
+#include <QString>
 #include <QStringList>
 #include <QQmlParserStatus>
 
@@ -72,7 +72,6 @@ public:
         DisplayOriginRole,
         CanUpgrade,
         PackageNameRole,
-        IsTechnicalRole,
         CategoryRole,
         CategoryDisplayRole,
         SectionRole,
@@ -128,6 +127,8 @@ public:
     Q_SCRIPTABLE void invalidateFilter();
     void invalidateSorting();
 
+    bool canFetchMore(const QModelIndex & parent) const override;
+    void fetchMore(const QModelIndex & parent) override;
     bool sortByRelevancy() const;
 
     void classBegin() override {}
